@@ -98,12 +98,12 @@ with Workflow(WORKFLOW_NAME) as workflow:
 
     images = get_migration_images_from_endpoints(
         supercell_start={
-            "calculation_table": "NEBEndpointRelaxation",
+            "calculation_table": "MatVirtualLabCINEBEndpointRelaxation",
             "directory": run_id_00["directory"],
             "structure_field": "structure_final",
         },
         supercell_end={
-            "calculation_table": "NEBEndpointRelaxation",
+            "calculation_table": "MatVirtualLabCINEBEndpointRelaxation",
             "directory": run_id_01["directory"],
             "structure_field": "structure_final",
         },
@@ -128,6 +128,8 @@ workflow.s3tasks = [
     relaxation_neb_endpoint_workflow.s3task,
     neb_from_images.s3task,
 ]
+
+workflow.description_doc_short = "runs NEB using two endpoint structures as input"
 workflow.__doc__ = """
     Runs a full diffusion analysis from a start and end supercell using NEB.
     
