@@ -18,6 +18,7 @@ def s3task_to_workflow(
     s3task: S3Task,
     calculation_table: Calculation,
     register_kwargs: List[str],
+    description_doc_short: str = None,
 ):
     """
     Builds a workflow from a S3Task and it's corresponding database table.
@@ -49,14 +50,14 @@ def s3task_to_workflow(
         command = Parameter("command", default="vasp_std > vasp.out")
         source = Parameter("source", default=None)
         directory = Parameter("directory", default=None)
-        use_previous_directory = Parameter("use_previous_directory", default=False)
+        copy_previous_directory = Parameter("copy_previous_directory", default=False)
 
         structure_toolkit, directory_cleaned = load_input_and_register(
             input_obj=structure,
             command=command,
             source=source,
             directory=directory,
-            use_previous_directory=use_previous_directory,
+            copy_previous_directory=copy_previous_directory,
         )
         output = s3task_obj(
             structure=structure_toolkit,
@@ -72,6 +73,7 @@ def s3task_to_workflow(
     workflow.register_kwargs = register_kwargs
     workflow.result_task = output
     workflow.s3task = s3task
+    workflow.description_doc_short = description_doc_short
 
     # by default we just copy the docstring of the S3task to the workflow
     workflow.__doc__ = s3task.__doc__
